; -*-Emacs-Lisp-*-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; File:         man-aids.el
; RCS:          $Header: man-aids.el,v 1.1 90/10/09 10:50:14 jad Exp $
; Description:  Extensions to the manual-entry command
; Author:       John A Dilley, Colorado Networks Division, Hewlett-Packard Co.
; Created:      Tue Oct  9 09:39:43 1990
; Modified:     Wed Apr 17 21:42:55 1991 (Carl Edman) cedman@lynx
; Language:     Emacs-Lisp
;
; (C) Copyright 1990, Hewlett-Packard Co., all rights reserved.
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;     
;;     This program is free software; you can redistribute it and/or
;;     modify it under the terms of the GNU General Public License as
;;     published by the Free Software Foundation; either version 1, or
;;     (at your option) any later version.
;;     
;;     This program is distributed in the hope that it will be useful,
;;     but WITHOUT ANY WARRANTY; without even the implied warranty of
;;     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;;     General Public License for more details.
;;     
;From: jad@hpcndnm.cnd.hp.com (John Dilley)
;Newsgroups: gnu.emacs
;Subject: Enhancement to man.el
;Date: 9 Oct 90 20:57:16 GMT
;Distribution: gnu
;Organization: Hewlett Packard, Colorado Networks Division
;Nntp-Posting-Host: hpcndnm.cnd.hp.com
;
;
;	I'm posting some extensions I've created to the manual-entry
;command.  The following replacement function first checks to see if the
;manual entry already exists (if you've done a manual-entry for that
;topic already) and if so reuses the buffer.  If not the function will
;call the system-defined manual-entry function, retrieve the manual
;information and then change the name of the "*Manual Entry*" buffer to
;"*topic.section*" so we can find it next time.  This won't be as useful
;to you if you don't do repeated manual-entry commands, though you may
;find the ability to have multiple (named) manual pages open easily.  Use
;it in health, and by all means forward enhancement requests to me!
;Thank you,
;
;                          --      jad      --
;			      John Dilley
;			    Hewlett-Packard
;                       Colorado Networks Division
;UX-mail:      		     jad@cnd.hp.com
;Phone:                       (303) 229-2787
;

(load "man")
(fset 'system-manual-entry (symbol-function 'manual-entry))

(defun jad-manual-entry (topic &optional section)
  "Display the Unix manual entry for TOPIC.
TOPIC is either the title of the entry, or has the form TITLE(SECTION)
where SECTION is the desired section of the manual, as in `tty(4)'."
  (interactive "sManual entry (topic): ")
  (if (and (null section)
	   (string-match "\\`[ \t]*\\([^( \t]+\\)[ \t]*(\\(.+\\))[ \t]*\\'" topic))
      (setq section (substring topic (match-beginning 2)
				     (match-end 2))
	    topic (substring topic (match-beginning 1)
				   (match-end 1))))
  (let ((man-buffer-name
	 (concat "*" topic "." (if section section "man") "*"))
	man-buffer)
    ;; Check to see if we already have a buffer with this manual entry.  If
    ;; so, display it.  If not, call system-manual-entry and rename it.
    (if (setq man-buffer (get-buffer man-buffer-name))
	;; Display the buffer containing the manual entry in another window
	;; but do not select it (don't change window-buffer correspondance)
	(display-buffer man-buffer)
      ;; Otherwise no buffer exists for this manual entry.  Create one and
      ;; then rename it to a more useful name ("*topic.section*")...
      (system-manual-entry topic section)
      (set-buffer (setq man-buffer (get-buffer "*Manual Entry*")))
      (rename-buffer man-buffer-name))))

(fset 'manual-entry (symbol-function 'jad-manual-entry))

